pilas.musica

Package pilas :: Module musica |
[hide private]
[frames] | no frames]

# Module musica

source code

Functions | [hide private]
cargar(ruta) Carga un canción para reproducir, donde el argumento ``ruta`` indica cual es el archivo. | source code

Variables | [hide private]
| __package__ = ``'``pilas``'``

Function Details | [hide private]

### cargar(ruta) | source code
    Carga un canción para reproducir, donde el argumento ``ruta`` indica cual es el archivo.

    Por ejemplo::

        >>> musica = pilas.musica.cargar("jazz_loop.ogg")

    En caso de éxito retorna el objeto Musica, que se puede
    reproducir usando el método ``reproducir()``, por ejemplo::

        >>> musica.reproducir(repetir=True)

    El directorio de búsqueda del sonido sigue el siguiente orden:

        * primero busca en el directorio actual.
        * luego en 'data'.
        * por último en el directorio estándar de la biblioteca.

    En caso de error genera una excepción de tipo IOError.

    :param ruta: La ruta al archivo a reproducir.